cordex.tables package
=====================

Subpackages
-----------

.. toctree::

   cordex.tables.data_request
   cordex.tables.domains

Module contents
---------------

.. automodule:: cordex.tables
   :members:
   :undoc-members:
   :show-inheritance:
